@@ -11,7 +11,7 @@ def get_level_color(levelno):
         logging.ERROR: textColor.RED,
         logging.WARNING: textColor.YELLOW,
         logging.INFO: textColor.GREEN,
-        logging.DEBUG: textColor.WHITE,
+        logging.DEBUG: '\033[1;30m',
         logging.NOTSET: textColor.WHITE,
     }.get(levelno, textColor.WHITE)
 
@@ -25,14 +25,15 @@ class CustomLoggingFormatter(logging.Formatter):
 
 
 def get_logger(logger_name='custom'):
+    formatter = CustomLoggingFormatter()
     sh = logging.StreamHandler()
     sh.setLevel(logging.DEBUG)
-    formatter = CustomLoggingFormatter()
     sh.setFormatter(formatter)
 
     log = logging.getLogger(logger_name)
+    log.propagate = False
     log.setLevel(logging.DEBUG)
-    log.addHandler(sh)
+    log.handlers = [sh]
     return log
 
 
