@@ -5,11 +5,14 @@ import time
 DEFAULT_TIME_FORMAT = '%Y-%m-%d %H:%M:%S'
 FORMAT_DATE = '%Y-%m-%d'
 FORMAT_DATE_ID = '%Y%m%d'
+FORMAT_TIME_ID = '%Y%m%d-%H%M%S'
+
+TIMEZONE_OFFSET_LK = -19_800
+TIMEZONE_OFFSET_GMT = 0
 
 
 class SECONDS_IN:
     """Units of time."""
-
     MINUTE = 60
     HOUR = 3600
     DAY = 86400
@@ -20,6 +23,18 @@ class SECONDS_IN:
     YEAR = 365.25 * 86400
 
 
+class AVG_DAYS_IN:
+    WEEK = 7
+    MONTH = 365.25 / 12
+    YEAR = 365.25
+
+
+def get_timezone_offset(timezone=None):
+    if timezone is None:
+        return 0
+    return timezone - time.timezone
+
+
 def get_timezone():
     """Get timezone."""
     return str(datetime.datetime.now().astimezone().tzinfo)
@@ -33,18 +48,23 @@ def get_unixtime():
 def parse_time(
     time_str,
     time_format=DEFAULT_TIME_FORMAT,
+    timezone=None,
 ):
     """Parse time string, and return unixtime."""
     _datetime = datetime.datetime.strptime(time_str, time_format)
-    return (int)(time.mktime(_datetime.timetuple()))
+    return (int)(time.mktime(_datetime.timetuple())) \
+        + get_timezone_offset(timezone)
 
 
 def format_time(
     unixtime,
     time_format=DEFAULT_TIME_FORMAT,
+    timezone=None,
 ):
     """Format unixtime as time string."""
-    _datetime = datetime.datetime.fromtimestamp(unixtime)
+    _datetime = datetime.datetime.fromtimestamp(
+        unixtime - get_timezone_offset(timezone),
+    )
     return _datetime.strftime(time_format)
 
 
@@ -55,52 +75,26 @@ def format_current_date_with_timezone():
     return '{date} {timezone}'.format(date=date, timezone=timezone)
 
 
-def get_date_id(unixtime=None):
+def get_date_id(unixtime=None, timezone=None,):
     """Get date id."""
     if unixtime is None:
         unixtime = get_unixtime()
-    return format_time(unixtime, FORMAT_DATE_ID)
+    return format_time(unixtime, FORMAT_DATE_ID, timezone)
 
 
-def get_date(unixtime=None):
+def get_time_id(unixtime=None, timezone=None,):
     """Get date id."""
     if unixtime is None:
         unixtime = get_unixtime()
-    return format_time(unixtime, FORMAT_DATE)
+    return format_time(unixtime, FORMAT_TIME_ID, timezone)
 
 
-class StopWatch:
-    """Implements StopWatch.
+def parse_date_id(date_id, timezone=None):
+    return parse_time(date_id, FORMAT_DATE_ID, timezone)
 
-    .. code-block:: python
 
-        >>> import time
-        >>> from utils import timex
-        >>> sw = timex.StopWatch()
-        >>> time.sleep(3)
-        >>> print(sw.stop('Test'))
-        3930.06706237793
-
-    """
-
-    def __init__(self):
-        """__init__."""
-        self.reset()
-
-    def reset(self):
-        """Reset StopWatch."""
-        self.t_start = time.time()
-
-    def stop(self, label=""):
-        """Stop StopWatch, print and return elapsed time.
-
-        Args:
-            label(str, optional): Optional label to prefix the output
-
-        Return:
-            Elapsed time in miliseconds (float)
-
-        """
-        delta_t = (time.time() - self.t_start) * 1000
-        print('{label} {delta_t}ms'.format(label=label, delta_t=delta_t))
-        return delta_t
+def get_date(unixtime=None, timezone=None):
+    """Get date id."""
+    if unixtime is None:
+        unixtime = get_unixtime()
+    return format_time(unixtime, FORMAT_DATE, timezone)
