@@ -11,21 +11,13 @@ DEFAULT_ATTRIB_MAP = {
     'svg': {
         'xmlns': 'http://www.w3.org/2000/svg',
     },
-    'text': {
-        'font-family': FONT_FAMILY,
-        'text-anchor': 'middle',
-        'fill': '#000000',
-        'stroke': 'none',
-    },
-    'text-gray': {
-        'font-family': FONT_FAMILY,
-        'text-anchor': 'middle',
-        'fill': '#c0c0c0',
-        'stroke': 'none',
-    },
 }
 
 
+def render_link_styles(css_file='styles.css'):
+    return _('link', None, {'rel': 'stylesheet', 'href': css_file})
+
+
 def style(**kwargs):
     style_content = ''.join(list(map(
         lambda item: '%s:%s;' % (dt.to_kebab(str(item[0])), str(item[1])),
